@@ -49,10 +49,8 @@ main(int argc, char** argv)
     try {
         if (main_window) kit.run(*main_window); 
         delete main_window;
-    }
-    catch (const std::exception& ex) {
+    } catch (const std::exception& ex) {
         LOG_EXCEPTION(ex.what());
-        return 1;
     }
 
     return 0;
