@@ -1,7 +1,5 @@
-// -*- Mode: C++; indent-tabs-mode: nil; c-basic-offset: 4 -*-
-
 /*
- * PaperBox - tag-cloud-model.cc
+ * Paperbox - tag-cloud-model.cc
  *
  * Copyright (C) 2007 Marko Anastasov
  *
@@ -25,7 +23,7 @@
 #include "tag-cloud-model.hh"
 
 using std::map;
-using boost::shared_ptr;
+using std::tr1::shared_ptr;
 
 class CloudStats
 {
